#
# Fecha de elaboración: Mie 23 Ene 2024
# Fecha de publicación: Mar 14 May 2024
# Santiago, Chile

# Autor: Área Macroeconómica del Subdepartamento de Estudios
#        Dirección de Presupuestos

# Versión: R 4.3.2
#          RStudio 2023.12.0+369

# En este código se calcula el balance estructural del Gobierno Central Total
# para el año 2023, complementando el informe 'Indicador del Balance Cíclicamente
# Ajustado. Metodología y Resultados'. Esta metodología sigue el Decreto N°346 de 
# septiembre de 2023 del Ministerio de Hacienda, el cuál regía para ese año. 
# Este decreto se encuentra disponible en: https://bcn.cl/3jqe2. 

# El insumo necesario para utilizar este código es la base de datos en Excel llamada
# 'Cuadros Indicador BCA 2023'. Esta base de datos contiene todos los cuadros del 
# informe, donde se exponen las variables estructurales, macroeconómicas y fiscales 
# para realizar el cálculo del balance estructural. Esta base de datos se encuentra 
# descargable junto al informe.

# El código se organiza de la siguiente manera:
#
#     2. datos.R: se importan los datos de los cuadros del Excel 'Cuadros Indicador
#                 BCA 2022' y se organizan en 'estructurales', 'económicos', 'elas-
#                 ticidades', 'eeoo' y 'tributarios'.
#     3. ajuste_itnm_iprevsalud.R: se calculan los ingresos tributarios no mineros 
#                                  estructurales, las imposiciones previsionales de 
#                                  salud estructurales y sus ajuste cíclicos.
#     4. ajuste_cbruto.R: se calculan los ingresos por cobre bruto estructurales y
#                         su ajuste cíclico.
#     5. ajuste_gmp10.R: se calculan los ingresos por impuesto a la renta de gmp10,
#                        impuesto específico a la actividad minera e impuesto adicio-
#                        nal estructurales y sus ajustes cíclicos.
#     6. bca.R: se calcula el balance cíclicamente ajustado (o estructural) con los
#               resultados de los cálculos anteriores.

# Se necesitan hacer solo dos ediciones:
#  1. Reemplazar en este script la carpeta del directorio en la función setwd
#  2. Reemplazar en este script la ruta del archivo excel con los datos.

# Directorio
# Reemplazar la ruta del directorio
setwd("D:/reemplazar carpeta de directorio")

# Liberías
# Verificar si las librerías están instaladas y, si no lo están, instalarlas
#install.packages("readxl")
#install.packages("dplyr")
#install.packages("tidyverse")

# Cargar las librerías necesarias
library(readxl)    # Importar datos en Excel
library(dplyr)     # Manipulación de datos
library(tidyverse) # Análisis de datos

# Simplificamos la ruta de la base de datos
ruta <- "D:/carpeta directorio/nombre del archivo excel con datos"

# Año de cierre fiscal
año_cierre <- 2023

######
###
#

source("2datos.R")
source("3ajuste_itnm_iprevsalud.R")
source("4ajuste_cbruto.R")
source("5ajuste_gmp10.R")
source("6bca.R")

