##############
######
##

# Variables Estructurales
# Cargar datos de las variables estructurales (Cuadro CII.1)
datos_estructurales <- read_excel(ruta, sheet = "C II.1", range = "B5:B11", col_names = FALSE) %>%
  t() %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Nombramos las variables
variables_CII1 <- c(
  "brpib_t",    # Brecha PIB de año_cierre (año actual)
  "brpib_ant",  # Brecha PIB de 2021 (año anterior)
  "pref_t",     # Precio de referencia de cobre de año_cierre (año actual)
  "pref_ant",   # Precio de referencia de cobre de 2021 (año anterior)
  "t_ie",       # Tasa de impuesto específico a la minería asociada al pref_ant
  "t_ir",       # Tasa de impuesto a la renta a la minería asociada al pref_ant
  "t_ia")       # Tasa de impuesto adicional a la minería asociada al pref_t
colnames(datos_estructurales) <- variables_CII1
rownames(datos_estructurales) <- año_cierre

# Variables Económicas
# Cargar datos de las variables económicas (Cuadro CII.2)
datos_economicos <- read_excel(ruta, sheet = "C II.2", range = "C5:C35", col_names = FALSE) %>%
  t() %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))

# Tasas efectivas de la minería privada (GMP10)
# Cargar datos de las tasas (Cuadro CII.4)
tasas_gmp10 <- read_excel(ruta, sheet = "C II.4", range = "B5:B7", col_names = FALSE) %>%
  t() %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))

# PPM trimestrales impuesto a la renta
# Cargar datos de los ppm de impuesto a la renta del año (Cuadro A.4.2)
ppmir_q <- read_excel(ruta, sheet = "C A.4.2", range = "D13:G13", col_names = FALSE) %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Cargar dato de PIB nominal año_cierre
pibn_añocierre <- read_excel(ruta, sheet = "C A.2", range = "E29:E29", col_names = FALSE) %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Pasamos las tasas gmp10, ppm de impuesto a la renta y el PIB del año de cierre a datos económicos
datos_economicos <- bind_cols(datos_economicos, tasas_gmp10, ppmir_q, pibn_añocierre)
rm(tasas_gmp10, ppmir_q, pibn_añocierre)

# Nombramos las variables
variables_CII2 <- c(
  "vpib_t",     # Variación real anual del PIB año_cierre
  "vipc_t",     # Variación real anual del promedio anuao del IPC año_cierre 
  "tcn_1t",     # Tipo de cambio nominal promedio primer trimestre año_cierre
  "tcn_2t",     # Tipo de cambio nominal promedio segundo trimestre año_cierre
  "tcn_3t",     # Tipo de cambio nominal promedio tercer trimestre año_cierre
  "tcn_4t",     # Tipo de cambio nominal promedio cuarto trimestre año_cierre
  "tcn_t",      # Tipo de cambio nominal promedio anual año_cierre
  "tcn_ant",    # Tipo de cambio nominal promedio anual 2021 ($año_cierre)
  "pbml_1t",    # Precio de cobre BML promedio primer trimestre año_cierre
  "pbml_2t",    # Precio de cobre BML promedio segundo trimestre año_cierre
  "pbml_3t",    # Precio de cobre BML promedio tercer trimestre año_cierre
  "pbml_4t",    # Precio de cobre BML promedio cuarto trimestre año_cierre
  "pbml_t",     # Precio de cobre BML promedio anual año_cierre
  "pbml_ant",   # Precio de cobre BML promedio anual 2021 ($año_cierre)
  "pcdlco_1t",    # Precio de cobre Codelco promedio primer trimestre año_cierre
  "pcdlco_2t",    # Precio de cobre Codelco promedio segundo trimestre año_cierre
  "pcdlco_3t",    # Precio de cobre Codelco promedio tercer trimestre año_cierre
  "pcdlco_4t",    # Precio de cobre Codelco promedio cuarto trimestre año_cierre
  "vcdlco_1t",    # Ventas de cobre Codelco primer trimestre año_cierre
  "vcdlco_2t",    # Ventas de cobre Codelco segundo trimestre año_cierre
  "vcdlco_3t",    # Ventas de cobre Codelco tercer trimestre año_cierre
  "vcdlco_4t",    # Ventas de cobre Codelco cuarto trimestre año_cierre
  "qgmp10_1t",    # Producción de cobre GMP10 primer trimestre año_cierre
  "qgmp10_2t",    # Producción de cobre GMP10 segundo trimestre año_cierre
  "qgmp10_3t",    # Producción de cobre GMP10 tercer trimestre año_cierre
  "qgmp10_4t",    # Producción de cobre GMP10 cuarto trimestre año_cierre
  "qgmp10_t",     # Producción de cobre GMP10 total año_cierre
  "qgmp10_ant",   # Producción de cobre GMP10 total 2021
  "zt",           # Proporción de distribución de las utilidades al exterior por las GMP10 (remesas)
  "copgmp10_t",     # Costos de operación totales de GMP10 año_cierre
  "copgmp10_ant",   # Costos de operación totales de GMP10 2021
  "t_ie_ef",    # Tasa de impuesto específico efectiva asociada al precio BML del año t-1
  "t_ir_ef",    # Tasa de impuesto a la renta de primera categoría año t-1 menos el crédito por t_ie_ef
  "t_ia_ef",    # Tasa de impuesto adicional del año t menos el crédito por t_ie_ef
  "ppmir_1t",  # PPM impuesto a la renta gmp10 primer trimestre año t 
  "ppmir_2t",  # PPM impuesto a la renta gmp10 segundo trimestre año t 
  "ppmir_3t",  # PPM impuesto a la renta gmp10 tercer trimestre año t 
  "ppmir_4t",  # PPM impuesto a la renta gmp10 cuarto trimestre año t 
  "pibn_añocierre"       # Producto Interno Bruto (PIB) nominal año_cierre
  )  
colnames(datos_economicos) <- variables_CII2
rownames(datos_economicos) <- año_cierre

# Elasticidades
# Cargamos los datos de elasticidades del cuadro C II.3
elasticidades <- read_excel(ruta, sheet = "C II.3", range = "B5:G5", col_names = FALSE) %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Nombramos las variables
variables_CII3 <- c(
  "e_ranual",    # Renta anual
  "e_rmensual",  # Renta mensual
  "e_ppm",       # Pagos provisionales mensuales
  "e_spago",     # Sistemas de pago
  "e_indir",     # Indirectos
  "e_otros"      # Otros
)
colnames(elasticidades) <- variables_CII3
rownames(elasticidades) <- año_cierre

# Estado de Operaciones
# Cargamos los datos de EEOO del cuadro C A.3
eeoo <- read_excel(ruta, sheet = "C A.3", range = "E8:E16", col_names = FALSE) %>%
  t() %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Venta de activos físicos, ingresos y gastos totales  
ranges <- c("E8:E16", "E27:E27", "E30:E31")
dfs <- map(ranges, ~read_excel(ruta, sheet = "C A.3", range = .x, col_names = FALSE) %>%
             t() %>%
             as.data.frame() %>%
             setNames(paste0("Variable_", seq_along(.))))
# Imposiciones previsionales de salud
ips <- read_excel(ruta, sheet = "C A.4.2", range = "H8", col_names = FALSE)
# Combinamos los datos
eeoo <- bind_cols(dfs, ips)
rm(dfs, ips)
# Nombramos las variables
variables_CA3 <- c(
  "itnm",           # Ingresos tributarios netos
  "trib_gmp10_eo",  # Tributación minería privada
  "rc",             # Tributación resto de contribuyentes
  "cobre",          # Cobre bruto
  "iprev",          # Imposiciones previsionales
  "don",            # Donaciones
  "rprop",          # Rentas de la propiedad
  "iope",           # Ingresos de operación
  "otros_eo",       # Otros ingresos
  "vactfis",        # Venta de activos físicos
  "i",              # Ingresos del gobierno central total
  "g",              # Gastos del gobierno central total
  "iprevsalud"      # Imposiciones previsionales de salud
)
colnames(eeoo) <- variables_CA3
rownames(eeoo) <- año_cierre

# Ingresos Tributarios
# Cargamos los datos de ingresos tributarios del cuadro C A.4.1
total <- read_excel(ruta, sheet = "C A.4.1", range = "F6:F31", col_names = FALSE) %>%
  t() %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Borramos los NA
total <- total[, colSums(is.na(total)) != nrow(total)]
# Nombramos las variables
variables_CA41 <- c(
  "irenta_t",    # Impuestos a la renta total   
  "danual_t",      # Declaración anual total
  "imp_t",           # Impuestos de declaración anual total  
  "spago_t",         # Sistemas de pago de declaración anual total 
  "dpm_t",         # Declaración y pago mensual
  "ppm_t",         # Pagos provisionales mensuales total
  "iva",         # Impuesto al valor agregado total
  "ivad",          # IVA declarado total
  "ceepp",         # Crédito Especial Empresas Constructoras   
  "dev",           # Devoluciones total
  "pesp",        # Impuesto a productos específicos
  "tcc",           # Tabaco, cigarros y cigarrillos
  "comb",          # Combustibles   
  "lpesca",        # Derechos de Extracción Ley de Pesca
  "actjur",      # Impuestos a los actos jurídicos  
  "comext",      # Impuestos al comercio exterior
  "otros_it",    # Otros      
  "fddp",          # Fluctuación deudores más diferencias pendientes
  "otr_o",         # Otros    
  "trib_t"     # Ingresos netos por impuestos total   
)
colnames(total) <- variables_CA41
rownames(total) <- año_cierre

# Tributación Mineria Privada (GMP10)
# Cargamos los datos de GMP10 del cuadro C A.4.2
gmp10 <- read_excel(ruta, sheet = "C A.4.2", range = "H11:H21", col_names = FALSE, skip = "blank") %>%
  t() %>%
  as.data.frame() %>%
  setNames(paste0("Variable_", seq_along(.)))
# Borramos los NA
gmp10 <- gmp10[, colSums(is.na(gmp10)) != nrow(gmp10)]
# Nombramos las variables
variables_CA42 <- c(
  "trib_gmp10",   # Tributación minería privada
  "irenta_gmp10",    # Impuesto a la renta gmp10 
  "ppmir_gmp10_t",         # PPM del año impuesto a la renta
  "ppmir_gmp10_ant",       # PPM del año anterior impuesto a la renta
  "declir",                # Impuesto declarado impuesto a la renta
  "iespcif_gmp10",   # Impuesto específico a la actividad minera
  "ppmie_gmp10_t",         # PPM del año impuesto específico
  "ppmie_gmp10_ant",       # PPM del año anterior impuesto específico
  "declie",                # Impuesto declarado impuesto específico
  "iadret"           # Impuesto adicional retenido
  )
colnames(gmp10) <- variables_CA42
rownames(gmp10) <- año_cierre

# Ingresos Tributarios No Mineros (ITNM)
# Restamos los ingresos de GMP10 de los ingresos tributarios totales
renta_nm <- data.frame(
  imp_nm = total$imp_t - gmp10$declir - gmp10$declie,         # Impuestos declarados resto de contribuyentes
  spago_nm = total$spago_t - gmp10$ppmir_gmp10_ant - gmp10$ppmie_gmp10_ant,   # Sistemas de pago resto de contribuyentes
  dpm_nm = total$dpm_t - gmp10$iadret,      # Declaración y pago mensual resto de contribuyentes
  ppm_nm = total$ppm_t - gmp10$ppmir_gmp10_t - gmp10$ppmie_gmp10_t  # Pagos provisionales mensuales resto de contribuyentes
)
renta_nm <- renta_nm %>%
  mutate(
  danual_nm = imp_nm + spago_nm,   # Declaración anual resto de contribuyentes
  irenta_nm = danual_nm + dpm_nm + ppm_nm   # Impuesto a la renta resto de contribuyentes
)
rownames(renta_nm) <- año_cierre

#Lista con las 3 bases de datos de ingresos tributarios
tributarios <- list(total = total, gmp10 = gmp10, renta_nm = renta_nm)

# Medidas tributarias transitorias de reversión automática
mttra <- read_excel(ruta, sheet = "C II.6", range = "C7", col_names = FALSE)
rownames(mttra) <- año_cierre
colnames(mttra) <- "mttra"

# Hacemos solo 1 base de datos que contenga las categorías
datos <- list(str     = datos_estructurales,
              macro   = datos_economicos,
              e       = elasticidades,
              eeoo    = eeoo,
              mttra   = mttra)
datos$trib <- tributarios   # añadimos la lista tributarios a la lista de datos

####
rm(datos_economicos, datos_estructurales, elasticidades, eeoo, tributarios, total, gmp10, renta_nm, mttra)
rm(variables_CA3, variables_CA41, variables_CA42, variables_CII1, variables_CII2, variables_CII3, ranges)

#################
#########
####
#

