##############
#######
##

# Ingresos tributarios no mineros (ITNM)

# Simplificamos las referencias de los datos que utilizamos
a <- datos$trib$renta_nm  # Referencia a imp a la renta resto de contribuyentes
b <- datos$str            # Referencia a datos estructurales
c <- datos$e              # Referencia a elasticidades
d <- datos$trib$total     # Referencia a impuestos indirectos
e <- datos$mttra          # Referencia a datos de mttra

# Cálculo de ITNM estructurales
itnm_str   <- data.frame(
  imp_nm_str   = a$imp_nm    * (1+b$brpib_ant)^c$e_ranual,             # impuestos de renta anual
  spago_nm_str = a$spago_nm  * (1+b$brpib_ant)^c$e_spago,              # sistemas de pago impuesto a la renta
  dpm_nm_str   = a$dpm_nm    * (1+b$brpib_t)  ^c$e_rmensual,           # declaración y pago mensual
  ppm_nm_str   = a$ppm_nm    * (1+b$brpib_t)  ^c$e_ppm,                # pagos provisionales mensuales
  indir_nm_str = ((d$iva+d$pesp+d$actjur+d$comext)-e$mttra) * (1+b$brpib_t)^c$e_indir, # impuestos indirectos
  otros_nm_str = d$otros_it  * (1+b$brpib_t)  ^c$e_otros               # otros tributarios
  )
itnm_str_total <- data.frame(
  itnm_str_total = itnm_str$imp_nm_str   +
                   itnm_str$spago_nm_str +
                   itnm_str$dpm_nm_str   +
                   itnm_str$ppm_nm_str   +
                   itnm_str$indir_nm_str +
                   itnm_str$otros_nm_str 
)
# Lista con la composición de los ingresos estructurales y el total
itnm_str <- bind_cols(itnm_str, itnm_str_total)

# Ajustes cíclicos
itnm_ac <- data.frame(
    imp_nm_ac   = a$imp_nm    - itnm_str$imp_nm_str,
    spago_nm_ac = a$spago_nm  - itnm_str$spago_nm_str,
    dpm_nm_ac   = a$dpm_nm    - itnm_str$dpm_nm_str,
    ppm_nm_ac   = a$ppm_nm    - itnm_str$ppm_nm_str,
    indir_nm_ac = (d$iva+d$pesp+d$actjur+d$comext)-itnm_str$indir_nm_str,
    otros_nm_ac = d$otros_it  - itnm_str$otros_nm_str
  )
itnm_ac_total <- data.frame(
  itnm_ac_total = itnm_ac$imp_nm_ac   +
                  itnm_ac$spago_nm_ac +
                  itnm_ac$dpm_nm_ac   +
                  itnm_ac$ppm_nm_ac   +
                  itnm_ac$indir_nm_ac +
                  itnm_ac$otros_nm_ac 
)
# Lista con la composición de los ajustes cíclicos y el total
itnm_ac <- bind_cols(itnm_ac, itnm_ac_total)
rm(a,b,c,d,e)

########
####
#


# Imposiciones previsionales de salud

# Simplificamos las referencias de los datos a utilizar
a <- datos$eeoo  # Referencia al estado de operaciones
b <- datos$str   # Referencia a los datos estructurales

# Cálculo de imposiciones previsionales de salud estructurales
iprevsalud_str <- data.frame(
  iprevsalud_str = a$iprevsalud*(1+b$brpib_t)^1.17)
# Ajustes cíclicos
iprevsalud_ac <- data.frame(
  iprevsalud_ac = a$iprevsalud-iprevsalud_str$iprevsalud_str)


######
###
#


i_str <- list(itnm_str       = itnm_str,
              iprevsalud_str = iprevsalud_str$iprevsalud_str)
ac    <- list(itnm_ac       = itnm_ac,
              iprevsalud_ac = iprevsalud_ac$iprevsalud_ac)
bca   <- list(i_str = i_str,
              ac    = ac)
rm(a,b)
rm(i_str, itnm_str_total , ac, iprevsalud_ac, iprevsalud_str, itnm_ac, itnm_str, itnm_ac_total)


#########
####
#