#############
#####
##

# Ingresos tributarios de la Gran Minería Privada (GMP10)

# Simplificamos las referencias de los datos que utilizamos
a <- datos$str         # Referencia a datos estructurales
b <- datos$macro       # Referencia a datos macroeconómicos
c <- datos$trib$gmp10  # Referencia a datos de tributación GMP10

########## 1. IMPUESTO A LA RENTA

# Cálculo del ajuste cíclico
# El ajuste cíclico de los PPM de impuesto a la renta se calcula en frecuencia trimestral
# y el ajuste cíclico anual es la suma trimestral

# PPM
ppm_trim_ac <- data.frame(
  ppm_1t_ac = ((b$pbml_1t - a$pref_t)/b$pbml_1t)*b$ppmir_1t,
  ppm_2t_ac = ((b$pbml_2t - a$pref_t)/b$pbml_2t)*b$ppmir_2t,
  ppm_3t_ac = ((b$pbml_3t - a$pref_t)/b$pbml_3t)*b$ppmir_3t,
  ppm_4t_ac = ((b$pbml_4t - a$pref_t)/b$pbml_4t)*b$ppmir_4t
) 
# Declaración anual y PPM del año anterior
# El ajuste cíclico de la declaración anual y de los PPM del año anterior se calculan en
# frecuencia anual
irenta_gmp10_ac = data.frame(
  declir_ac = (b$qgmp10_ant*2.20462*(b$pbml_ant*b$t_ir_ef - a$pref_ant*a$t_ir)-(b$copgmp10_ant*(b$t_ir_ef - a$t_ir)))*b$tcn_ant,
  ppmir_gmp10_ant_ac = ((b$pbml_ant - a$pref_ant)/b$pbml_ant)*c$ppmir_gmp10_ant,
  ppmir_gmp10_ac = ppm_trim_ac$ppm_1t_ac+   # Suma de ajustes cíclicos trimestrales
                   ppm_trim_ac$ppm_2t_ac+
                   ppm_trim_ac$ppm_3t_ac+
                   ppm_trim_ac$ppm_4t_ac)

# Ajuste cíclico total de impuesto a la renta GMP10
irtotal_gmp10_ac <- data.frame(      
  ir_gmp10_ac = irenta_gmp10_ac$ppmir_gmp10_ac     +
                irenta_gmp10_ac$declir_ac          +
                irenta_gmp10_ac$ppmir_gmp10_ant_ac)
irenta_gmp10_ac <- bind_cols(irenta_gmp10_ac, irtotal_gmp10_ac)

# Cálculo de los ingresos estructurales por impuesto a la renta gmp10
ir_gmp10_str = data.frame(
  declir_gmp10_str =      c$declir          - irenta_gmp10_ac$declir_ac,
  ppmir_gmp10_str =       c$ppmir_gmp10_t   - irenta_gmp10_ac$ppmir_gmp10_ac,
  ppmir_gmp10_ant_str =   c$ppmir_gmp10_ant - irenta_gmp10_ac$ppmir_gmp10_ant_ac,
  ir_gmp10_str =          c$irenta_gmp10    - irenta_gmp10_ac$ir_gmp10_ac
)

################

########## 2. IMPUESTO ESPECÍFICO A LA MINERÍA

# Cálculo del ajuste cíclico
# PPM del año, declaración anual y PPM del año anterior
# Todos los componentes se calculan en frecuencia anual
iesp_gmp10_ac <- data.frame(
  declie_ac =           (b$qgmp10_ant*2.20462*(b$pbml_ant*b$t_ie_ef - a$pref_ant*a$t_ie)-(b$copgmp10_ant*(b$t_ie_ef - a$t_ie)))*b$tcn_ant,
  ppmie_gmp10_ac =      ((b$pbml_t - a$pref_t)/b$pbml_t)*c$ppmie_gmp10_t,
  ppmie_gmp10_ant_ac =  ((b$pbml_ant - a$pref_ant)/b$pbml_ant)*c$ppmie_gmp10_ant   
)
ietotal_gmp10_ac <- data.frame(      # Ajuste cíclico total de impuesto específico a la minería privada
    ie_gmp10_ac = iesp_gmp10_ac$ppmie_gmp10_ac +
                  iesp_gmp10_ac$declie_ac      +
                  iesp_gmp10_ac$ppmie_gmp10_ant_ac)
iesp_gmp10_ac <- bind_cols(iesp_gmp10_ac, ietotal_gmp10_ac)

# Cálculo de los ingresos estructurales por impuesto específico a la actividad minera gmp10
ie_gmp10_str <- data.frame(
  declie_gmp10_str =      c$declie          - iesp_gmp10_ac$declie_ac,
  ppmie_gmp10_str =       c$ppmie_gmp10_t   - iesp_gmp10_ac$ppmie_gmp10_ac,
  ppmie_gmp10_ant_str =   c$ppmie_gmp10_ant - iesp_gmp10_ac$ppmie_gmp10_ant_ac,
  ie_gmp10_str =          c$iespcif_gmp10   - iesp_gmp10_ac$ie_gmp10_ac)



##################

########## 3. IMPUESTO ADICIONAL

# Cálculo del ajuste cíclico
# El ajuste cíclico del impuesto adicional se calcula en frecuencia trimestral y
# el ajuste cíclico anual es la suma trimestral
# Supuesto: los costos operacionales de GMP10 es igual para cada trimestre, es decir,
# el dato anual dividido 4 (copgmp10/4)
ia_gmp10_trim <- data.frame(
  ia_gmp10_1t_ac = b$zt*b$tcn_1t*((b$qgmp10_1t*2.20462*(b$pbml_1t*(b$t_ia_ef-b$t_ir_ef)-a$pref_t*(a$t_ia-a$t_ir)))-(b$copgmp10_t/4)*((b$t_ia_ef-b$t_ir_ef)-(a$t_ia-a$t_ir))),
  ia_gmp10_2t_ac = b$zt*b$tcn_2t*((b$qgmp10_2t*2.20462*(b$pbml_2t*(b$t_ia_ef-b$t_ir_ef)-a$pref_t*(a$t_ia-a$t_ir)))-(b$copgmp10_t/4)*((b$t_ia_ef-b$t_ir_ef)-(a$t_ia-a$t_ir))),
  ia_gmp10_3t_ac = b$zt*b$tcn_3t*((b$qgmp10_3t*2.20462*(b$pbml_3t*(b$t_ia_ef-b$t_ir_ef)-a$pref_t*(a$t_ia-a$t_ir)))-(b$copgmp10_t/4)*((b$t_ia_ef-b$t_ir_ef)-(a$t_ia-a$t_ir))),
  ia_gmp10_4t_ac = b$zt*b$tcn_4t*((b$qgmp10_4t*2.20462*(b$pbml_4t*(b$t_ia_ef-b$t_ir_ef)-a$pref_t*(a$t_ia-a$t_ir)))-(b$copgmp10_t/4)*((b$t_ia_ef-b$t_ir_ef)-(a$t_ia-a$t_ir)))
)
iadic_gmp10_ac <- data.frame(
  ia_gmp10_ac = ia_gmp10_trim$ia_gmp10_1t_ac+   # Suma de ajustes trimestrales
                ia_gmp10_trim$ia_gmp10_2t_ac+
                ia_gmp10_trim$ia_gmp10_3t_ac+
                ia_gmp10_trim$ia_gmp10_4t_ac)

# Cálculo ingresos estructurales por impuesto adicional a la minería privada
ia_gmp10_str <- data.frame(
  ia_gmp10_str = c$iadret - iadic_gmp10_ac$ia_gmp10_ac)

# Calculamos totales GMP10 str y ac
gmp10_str_total = data.frame(
  gmp10_str_total = ir_gmp10_str$ir_gmp10_str + ie_gmp10_str$ie_gmp10_str + ia_gmp10_str$ia_gmp10_str)
gmp10_ac_total = data.frame(
  gmp10_ac_total = irenta_gmp10_ac$ir_gmp10_ac + iesp_gmp10_ac$ie_gmp10_ac + iadic_gmp10_ac$ia_gmp10_ac)


#########
####
#

gmp10_str <- list(ir_gmp10_str    = ir_gmp10_str,
                  ie_gmp10_str    = ie_gmp10_str,
                  ia_gmp10_str    = ia_gmp10_str,
                  gmp10_str_total = gmp10_str_total$gmp10_str_total)

bca$i_str$gmp10_str <- gmp10_str

gmp10_ac <- list(ir_gmp10_ac    = irenta_gmp10_ac,
                 ie_gmp10_ac    = iesp_gmp10_ac,
                 ia_gmp10_ac    = iadic_gmp10_ac,
                 gmp10_ac_total = gmp10_ac_total$gmp10_ac_total)

bca$ac$gmp10_ac <- gmp10_ac

rm(ir_gmp10_str, irenta_gmp10_ac, irtotal_gmp10_ac, ppm_trim_ac)
rm(ie_gmp10_str, iesp_gmp10_ac, ietotal_gmp10_ac)
rm(ia_gmp10_str, iadic_gmp10_ac, ia_gmp10_trim)
rm(a,b,c)
rm(gmp10_ac, gmp10_ac_total, gmp10_str, gmp10_str_total)


########
####
#
